import { Api } from './api';
import { LOG_LEVEL } from '@ztimson/utils';
import { PathedEventEmitter } from './pathed-events';
export type LogLevel = 'ERROR' | 'WARN' | 'INFO' | 'LOG' | 'DEBUG' | 'NONE';
export type Log<T> = {
    time: Date;
    level: LOG_LEVEL;
    log: any[];
    ctx?: T;
};
export type ClientLog = Log<{
    url: string;
    user: string;
    ip: string;
    cores: number | 'Unknown';
    mem: number | 'Unknown';
    res: [number, number];
    ua: string | {
        ua: string;
        browser: {
            name: string;
            version: string;
            major: string;
        };
        cpu: {
            architecture: string;
        };
        device: {
            mode?: string;
            type?: string;
        };
        engine: {
            name: string;
            version: string;
        };
        os: {
            name: string;
            version: string;
        };
    };
}>;
export declare class Logger extends PathedEventEmitter {
    readonly namespace: string;
    private readonly api;
    constructor(api: Api | string, namespace: string, logLevel?: LogLevel | null);
    private buildLog;
    private createLog;
    clearLogs(namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
    clearServerLogs(): import('@ztimson/utils').PromiseProgress<any>;
    getLogs(length?: number, page?: number, namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
    getServerLogs(length?: number, page?: number): Promise<Log<any>[]>;
    debug(log: any, namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
    log(log: any, namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
    info(log: any, namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
    warn(log: any, namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
    error(log: any, namespace?: string): import('@ztimson/utils').PromiseProgress<any>;
}
//# sourceMappingURL=logger.d.ts.map